@@ -198,6 +198,11 @@ Measure = R6Class("Measure",
     #' @return `numeric(1)`.
     aggregate = function(rr) {
       if (self$average == "macro") {
+        learner = rr$data$learners(view = rr$view, states = FALSE, reassemble = FALSE)$learner[[1L]]
+        predict_sets = learner$predict_sets
+        if (any(self$predict_sets %nin% predict_sets)) {
+          stopf("Measure '%s' requires predict sets %s", self$id, str_collapse(self$predict_type, quote = "'"))
+        }
         aggregator = self$aggregator %??% mean
         tab = score_measures(rr, list(self), reassemble = FALSE, view = rr$view)
         set_names(aggregator(tab[[self$id]]), self$id)
