@@ -231,8 +231,9 @@ Resampling = R6Class("Resampling",
       i = assert_int(i, lower = 1L, upper = self$iters, coerce = TRUE)
       ids = getter(i)
 
-      if (is.null(private$.groups))
+      if (is.null(private$.groups)) {
         return(ids)
+      }
 
       private$.groups[list(ids), on = "group", allow.cartesian = TRUE][[1L]]
     }
