@@ -18,10 +18,10 @@ phashes = function(x) {
 
 hash = function(...) {
   dots = list(...)
-  is_fun = map_lgl(dots, is.function)
-  dots[is_fun] = map(dots[is_fun], function(fun) {
-    list(formals = formals(fun), body = as.character(body(fun)))
+  dots = map_if(dots, is.function, function(fun) {
+    list(formals(fun), as.character(body(fun)))
   })
+  dots = map_if(dots, is.data.table, as.list)
   digest::digest(dots, algo = "xxhash64")
 }
 
