@@ -60,15 +60,17 @@ as.data.table.DictionaryTask = function(x, ...) {
   setkeyv(map_dtr(x$keys(), function(key) {
     t = tryCatch(x$get(key),
       missingDefaultError = function(e) NULL)
-    if (is.null(t))
+    if (is.null(t)) {
       return(list(key = key))
+    }
 
     feats = translate_types(t$feature_types$type)
     insert_named(list(
       key = key,
       task_type = t$task_type,
       nrow = t$nrow,
-      ncol = t$ncol
+      ncol = t$ncol,
+      properties = list(t$properties)
     ), table(feats))
   }, .fill = TRUE), "key")[]
 }
