@@ -206,3 +206,35 @@ test_that("ordered", {
     ordered(c("1", NA, "0"), levels = c("1", "0"))
   )
 })
+
+test_that("POSIXct", {
+  expect_identical(
+    auto_convert(NA, "x", "POSIXct", character()),
+    .POSIXct(NA, "")
+  )
+
+  expect_identical(
+    auto_convert(NA_integer_, "x", "POSIXct", character()),
+    .POSIXct(NA, "")
+  )
+
+  expect_identical(
+    auto_convert(NA_real_, "x", "POSIXct", character()),
+    .POSIXct(NA_real_, "")
+  )
+
+  expect_identical(
+    auto_convert(factor(NA_character_, levels = "a"), "x", "POSIXct", "a"),
+    .POSIXct(NA, "")
+  )
+
+  expect_identical(
+    auto_convert(ordered(NA_character_, levels = "a"), "x", "POSIXct", "a"),
+    .POSIXct(NA, "")
+  )
+
+  expect_identical(
+    auto_convert("2020-01-20 10:00:00", "x", "POSIXct", character()),
+    as.POSIXct("2020-01-20 10:00:00", "")
+  )
+})
