@@ -93,7 +93,7 @@ test_that("convert_task reconstructs task", {
   task = mlr_tasks$get("iris")
   tsk = convert_task(task)
   tsk$man = "mlr3::mlr_tasks_iris"
-  expect_equal(task, tsk, check.attributes = FALSE)
+  expect_equal(task, tsk, ignore_attr = TRUE)
 
   task2 = task$filter(1:100)
   tsk2 = convert_task(task2)
@@ -108,7 +108,7 @@ test_that("convert_task reconstructs task", {
   expect_equal(task3$nrow, tsk3$nrow)
   expect_equal(task3$ncol, tsk3$ncol)
   expect_true("multiclass" %in% tsk3$properties)
-  expect_equal(task, tsk3, check.attributes = FALSE)
+  expect_equal(task, tsk3, ignore_attr = TRUE)
 })
 
 test_that("extra args survive the roundtrip", {
