@@ -1,10 +1,9 @@
+task = tsk("iris")
+learner = lrn("classif.featureless")
+resampling = rsmp("cv", folds = 3)
+rr = resample(task, learner, resampling)
+
 test_that("resample", {
-  task = tsk("iris")
-  learner = lrn("classif.featureless")
-  resampling = rsmp("cv", folds = 3L)
-
-  rr = resample(task, learner, resampling, store_models = TRUE)
-
   expect_resample_result(rr)
 
   scores = rr$score(msr("classif.ce"))
@@ -15,7 +14,7 @@ test_that("resample", {
   expect_different_address(learners[[1L]], learners[[2L]])
   expect_equal(uniqueN(hashes(learners)), 1L)
 
-  rr$filter(2:3)
+  rr = rr$clone(TRUE)$filter(2:3)
   tab = as.data.table(rr)
   expect_data_table(tab, nrows = 2L)
   expect_data_table(tab, nrows = 2L)
@@ -29,10 +28,6 @@ test_that("empty RR", {
 })
 
 test_that("resample with no or multiple measures", {
-  task = tsk("iris")
-  learner = lrn("classif.featureless")
-  rr = resample(task, learner, rsmp("cv", folds = 3))
-
   for (measures in list(mlr_measures$mget(c("classif.ce", "classif.acc")), list())) {
     tab = rr$score(measures, ids = FALSE)
     expect_data_table(tab, ncols = length(mlr_reflections$rr_names) + length(measures), nrows = 3L)
@@ -44,11 +39,7 @@ test_that("resample with no or multiple measures", {
 })
 
 test_that("as_benchmark_result.ResampleResult", {
-  task = tsk("iris")
   measures = list(msr("classif.ce"), msr("classif.acc"))
-  learner = lrn("classif.featureless")
-  resampling = rsmp("cv", folds = 3)
-  rr = resample(task, learner, resampling)
   bmr = as_benchmark_result(rr)
   expect_benchmark_result(bmr)
   expect_equal(nrow(bmr$data), nrow(rr$data))
@@ -60,32 +51,16 @@ test_that("as_benchmark_result.ResampleResult", {
 
 
 test_that("discarding model", {
-  task = tsk("iris")
-  learner = lrn("classif.featureless")
-  resampling = rsmp("cv", folds = 3)
-
-  rr = resample(task, learner, resampling)
   expect_equal(map(as.data.table(rr)$learner, "model"), vector("list", 3L))
 })
 
 test_that("inputs are cloned", {
-  task = tsk("iris")
-  learner = lrn("classif.featureless")
-  resampling = rsmp("holdout")
-  resampling$instantiate(task)
-
-  rr = resample(task, learner, resampling)
   expect_different_address(task, rr$data$data$tasks$task[[1]])
   expect_different_address(learner, rr$data$data$learners$learner[[1]])
   expect_different_address(resampling, rr$data$data$resamplings$resampling[[1]])
 })
 
 test_that("memory footprint", {
-  task = tsk("iris")
-  learner = lrn("classif.featureless")
-  resampling = rsmp("cv", folds = 3)
-  rr = resample(task, learner, resampling)
-
   expect_equal(nrow(rr$data$data$learners), 1L)
   expect_equal(nrow(rr$data$data$tasks), 1L)
   expect_equal(nrow(rr$data$data$resamplings), 1L)
@@ -110,7 +85,7 @@ test_that("seeds work identical sequential/parallel", {
   measure = msr("classif.auc")
 
   rr1 = with_seed(123, with_future(future::plan("sequential"), resample(task, learner, resampling)))
-  rr2 = with_seed(123, with_future(future::plan("multiprocess"), resample(task, learner, resampling)))
+  rr2 = with_seed(123, with_future(future::plan("multisession"), resample(task, learner, resampling)))
 
   expect_equal(
     as.data.table(rr1$prediction())$prob.M,
@@ -133,3 +108,7 @@ test_that("empty train/predict sets", {
   resampling = rsmp("holdout", ratio = 1)
   expect_prediction(resample(task, learner, resampling)$predictions()[[1]])
 })
+
+test_that("conditions are returned", {
+  expect_true(all(c("warnings", "errors") %in% names(rr$score(conditions = TRUE))))
+})
